#!/usr/bin/python
# -*- coding: utf8 -*-

# ################################################################################  
# ## Redistributions of source code must retain the above copyright notice
# ## DATE: 2011-05-17  
# ## AUTHOR: SecPoint ApS  
# ## MAIL: info@secpoint.com  
# ## SITE: http://www.secpoint.com  
# ##
# ## LICENSE: BSD http://www.opensource.org/licenses/bsd-license.php
# ################################################################################  
# ## 1.0 initial release
# ## 1.1 google query generating option (-q)
# ## 1.2 generating HTML output

from optparse import OptionParser
import os.path
from urllib import quote_plus
 
VERSION = '1.2'

def get_strings(src_file):
    """getting strings from file"""
    res = []
    try:
        res = open(src_file,'r').readlines()
        res = [x.strip() for x in res]
    except:
        res = []
    return res

def append_sitename(strs,site):
    """adding site name to strings"""
    strs = [x+' site:'+site for x in strs]
    return strs

def gen_google_query(strs):
    """generating Google query strings for each line"""
    qs=[]
    gstring = "http://www.google.com/search?q="
    for x in strs:
            qs.append(gstring+quote_plus(x))
    return [strs,qs]

def gen_html_output(strs,q):
    """generating pretty HTML output"""
    res = []
    res.append('<html>\n')
    res.append('<head><title>SecPoint.com GoogleDB queries strings</title></head>\n')
    res.append('<body>\n')
    res.append('<p>Generated by: <a href="http://www.secpoint.com/">SecPoint.com</a> GoogleDB tool</p>\n')
    res.append('\t<ul>\n')
    for (x,v) in zip(strs,q):
        res.append('\t\t<li><a href="%s">%s</a></li>\n'%(v,x))
    res.append('\t</ul>\n')
    res.append('</body>\n</html>')
    return res

def save_output(strs,out_f):
    """saving/printing results"""
    res = "\n".join(strs)

    if out_f:
        try:
            open(out_f,'w').write(res)
        except:
            print "Error! Couldn't save output file!"
            exit()
    else:
        print res

def main():
    """Parsing options and starting engine"""
    parser = OptionParser(usage="%prog <sourcefile> [-s site] [-q] [-t] [-f outfile]", 
              version="SecPoint.com %prog "+VERSION,
              epilog="SecPoint.com Google Penetration Testing Hack Database v. "+VERSION)
    parser.add_option("-o", "--output", dest="filename",
                      help="save output to file", metavar="FILE")
    parser.add_option("-s", "--site", dest="sitename",
                      help="generate queries for the SITE", metavar="SITE")
    parser.add_option("-q", "--query",
                      action="store_true", dest="gen_query", default=False,
                      help="generate google query urls for each line")
    parser.add_option("-t", "--html",
                      action="store_true", dest="gen_html", default=False,
                      help="generate output in HTML format (implies -q)")
    (options, args) = parser.parse_args()
    if len(args) != 1:
        parser.print_help()
        exit()
        #parser.error("please set source file (could be found in 'db' dir)")
    #all options 
    site_name = options.sitename
    gen_html = options.gen_html
    gen_query = options.gen_query
    out_file = options.filename
    db_dir = os.path.join(os.path.dirname(__file__),'db')
    source_file = os.path.join(db_dir,args[0])
    if not os.path.isfile(source_file):
        parser.error("could not find source file! Please check if it exists in 'db' dir")

    #starting!
    strs = get_strings(source_file)
    if not strs:
        print "Can't get data from your source file!"
        exit()
    queries = []
    if site_name:
        strs = append_sitename(strs,site_name)
    if gen_query:
        [strs,queries] = gen_google_query(strs)
    if gen_html:
        if not gen_query: #if not previuosly generated
            [strs,queries] = gen_google_query(strs)
        strs = gen_html_output(strs,queries)
    else:
        if queries:   
            strs = queries

    save_output(strs,out_file)


if __name__ == "__main__":
    main()
